@@ -48,6 +48,10 @@ class UrlConfig:
     GET_SERVER_FROM_MERCHANT = "{host}/adm/{version}/server-uri/merchant"
     GET_LIST_SERVER_FROM_MODULE = "{host}/adm/{version}/server-uri"
     GET_DETAIL_MERCHANT_CONFIG = "{host}/adm/{version}/merchants/{merchant_id}/config/detail"
+    GET_LIST_FIELD_CONFIG_ENCRYPT = "{host}/adm/{version}/field-encrypt/config/list"
+    GET_DETAIL_KMS_CONFIG = "{host}/adm/{version}/field-encrypt/kms/detail"
+    GET_TOKEN_KMS_CONFIG = "{host}/adm/{version}/field-encrypt/token"
+
 
 class KafkaTopic:
     LogActionAccount = "admin-log-action-account"
@@ -65,3 +69,16 @@ class LicenseFormat:
     time_expire = "time_expire"
     server_name = "server_name"
     ALL_FIELD = [version, time_expire, server_name]
+
+class CodeErrorEncrypt:
+    encrypt_error = "encrypt_error"
+    encrypt_api_error = "encrypt_api_error"
+    encrypt_api_timeout = "encrypt_api_timeout"
+
+class CodeErrorDecrypt:
+    decrypt_error = "decrypt_error"
+    decrypt_api_error = "decrypt_api_error"
+    decrypt_api_timeout = "decrypt_api_timeout"
+
+class RedisKeyCache:
+    kms_viettel_get_token = "admin#kms_viettel_get_token_{}"
