@@ -23,3 +23,6 @@ def convert_timestamp_to_date_utc(timestamp):
             return None
     except:
         return None
+
+def get_timestamp_utc_now():
+    return round(datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc).timestamp())
