@@ -4,7 +4,7 @@ from .config import StoreCacheType, Cache, SystemConfigKeys
 from .mobio_authorization import MobioAuthorization
 from .http_jwt_auth import HttpJwtAuth
 # from mobio.libs.ciphers import MobioCrypt2
-import redis
+import redis, os
 from mobio.sdks.license import MobioLicenseSDK
 from .aes_cipher import CryptUtil
 
@@ -23,8 +23,7 @@ def sdk_pre_check(func):
             raise ValueError("admin_version invalid")
         # if not MobioAdminSDK().module_valid:
         #     raise ValueError("module invalid")
-        if SystemConfigKeys.vm_type and not CryptUtil.license_server_valid():
-            raise ValueError("license server invalid")
+
         return func(*args, **kwargs)
 
     return decorated_function
@@ -44,6 +43,7 @@ class MobioAdminSDK(object):
         self.request_header = None
         self.module_valid = False
         self.redis_uri = None
+        self.redis_connection = None
 
     @property
     def p_module_valid(self):
@@ -71,18 +71,19 @@ class MobioAdminSDK(object):
         #     #     self.module_valid = False
         #     self.module_valid = True
 
+        if SystemConfigKeys.vm_type and not CryptUtil.license_server_valid():
+            raise ValueError("license server invalid")
 
-        if redis_uri:
-            self.redis_uri = redis_uri
-            MobioAdminSDK.lru_cache = LruCache(
-                store_type=StoreCacheType.REDIS,
-                cache_prefix=Cache.PREFIX_KEY,
-                redis_uri=redis_uri,
-            )
-
+        self.redis_uri = "{}?health_check_interval=30".format(os.environ.get("ADMIN_REDIS_URI", os.environ.get("REDIS_URI")))
+        MobioAdminSDK.lru_cache = LruCache(
+            store_type=StoreCacheType.REDIS,
+            cache_prefix=Cache.PREFIX_KEY,
+            redis_uri=self.redis_uri,
+        )
+        self.redis_connection = redis.from_url(self.redis_uri)
         MobioLicenseSDK().config(
             admin_host=admin_host,
-            redis_uri=redis_uri,
+            redis_uri=os.environ.get("REDIS_URI"),
             module_use=module_use,
             module_encrypt=module_encrypt,
             license_key=SystemConfigKeys.LICENSE_KEY,
@@ -343,3 +344,36 @@ class MobioAdminSDK(object):
     ):
         from .utils import get_partner_info_decrypt
         return get_partner_info_decrypt(partner_key=partner_key, decrypt=decrypt_data)
+
+    @staticmethod
+    @sdk_pre_check
+    def push_message_to_kafka(topic:str, data:dict, key=None):
+        from .utils import push_message_kafka
+        return push_message_kafka(topic, data, key)
+
+    @staticmethod
+    @sdk_pre_check
+    def get_fields_config_encrypt(merchant_id, module):
+        from .utils import get_list_fields_config_encrypt
+        return get_list_fields_config_encrypt(merchant_id, module)
+
+    @staticmethod
+    @sdk_pre_check
+    def encrypt_values(merchant_id, module, field, values):
+        from .utils import encrypt_field_by_config
+        return encrypt_field_by_config(merchant_id, module, field, values)
+
+    @staticmethod
+    @sdk_pre_check
+    def decrypt_values(merchant_id, module, field, values):
+        from .utils import decrypt_field_by_config
+        return decrypt_field_by_config(merchant_id, module, field, values)
+
+    def redis_get_value(self, key_cache):
+        return self.redis_connection.get(key_cache)
+
+    def redis_set_value_expire(self, key_cache, value_cache, time_seconds=3600):
+        self.redis_connection.setex(key_cache, time_seconds, value_cache)
+
+    def redis_delete_key(self, key_cache):
+        self.redis_connection.delete(key_cache)
\ No newline at end of file
