@@ -42,7 +42,7 @@ class MobioAuthorization(ProjectAuthorization):
                 b_json = json.loads(Base64.decode(jwt_token.split(".")[1]))
                 merchant_id = b_json.get("merchant_id", None)
             except Exception as e:
-                print("admin_sdk:: __merchant_id__ error: {}".format(e))
+                print("admin_sdk:: __merchant_id__ error: {}, jwt_token: {}".format(e, jwt_token))
                 merchant_id = None
 
         if not merchant_id:
@@ -75,28 +75,31 @@ class MobioAuthorization(ProjectAuthorization):
         try:
             merchant_id = MobioAuthorization.__merchant_id__(token)
             self.key, self.algorithm = MobioAuthorization.get_auth_info(merchant_id)
+            body = self._decode(token)
+            if body is None:
+                return None
+            return body.get(field_name, None)
         except Exception as e:
             self.key = None
             self.algorithm = None
-            raise e
+            print("admin_sdk::get key in token: {} ; field_name: {}, err: {}".format(token, field_name, str(e)))
+            raise ValueError("get key in token: {}".format(e))
 
-        body = self._decode(token)
-        if body is None:
-            return None
-        return body.get(field_name, None)
 
     def _encode(self, body):
         try:
             return jwt.encode(body, self.key, self.algorithm)
         except Exception as e:
-            print("admin_sdk::can not encode token: %s ; key: {}, algorithm: {}".format(str(e), self.key, self.algorithm))
+            print("admin_sdk::can not encode token: {} ; key: {}, algorithm: {}".format(str(e), self.key,
+                                                                                       self.algorithm))
             return None
 
     def _decode(self, body):
         try:
             return jwt.decode(body, self.key, self.algorithm, self.options)
         except Exception as e:
-            print("admin_sdk::can not decode token: %s ; key: {}, algorithm: {}".format(str(e), self.key, self.algorithm))
+            print("admin_sdk::can not decode token: {} ; key: {}, algorithm: {}".format(str(e), self.key,
+                                                                                       self.algorithm))
             return None
 
     def is_permitted(self, jwt_token, typically, method):
@@ -124,34 +127,37 @@ class MobioAuthorization(ProjectAuthorization):
             #     return None
 
             # check key
-            mobio_key = request.headers.get(SystemConfigKeys.X_MOBIO_KEY, None)
-            mobio_key_valid = check_basic_auth_v2(mobio_key) if mobio_key else False
-            if mobio_key_valid:
-                return mobio_key
-            else:
-                if typically == TYPICALLY.BEARER or typically == TYPICALLY.DIGEST:
-                    is_staff = self.get(jwt_token, "is_mobio") is not None
-                    if is_staff and typically != TYPICALLY.BEARER:
-                        raise ValueError(
-                            "admin_sdk::typically invalidated, this must is %s" % TYPICALLY.BEARER
-                        )
-                    if (not is_staff) and typically != TYPICALLY.DIGEST:
-                        raise ValueError(
-                            "admin_sdk::typically invalidated, this must is %s" % TYPICALLY.DIGEST
-                        )
-                    arr_token = jwt_token.split(".")
-                    # kiểm tra token trong REDIS
-                    verify_token = arr_token[2]
-                    value = self.local_redis.get(verify_token)
-                    if not value:
-                        raise ValueError("admin_sdk::verify_token: {} not found in redis".format(verify_token))
-                    return jwt_token
+            # try:
+            #     mobio_key = request.headers.get(SystemConfigKeys.X_MOBIO_KEY, None)
+            #     mobio_key_valid = check_basic_auth_v2(mobio_key) if mobio_key else False
+            #     if mobio_key_valid:
+            #         return mobio_key
+            # except Exception as e:
+            #     print("admin_sdk::check x-mobio-key: ERROR: %s" % e)
 
-                elif typically == TYPICALLY.BASIC:
-                    if not check_basic_auth_v2(jwt_token):
-                        if not MobioAuthorization.check_app_data_out(jwt_token):
-                            raise ValueError("admin_sdk:: {} basic key invalid".format(jwt_token))
-                    return jwt_token
+            if typically == TYPICALLY.BEARER or typically == TYPICALLY.DIGEST:
+                is_staff = self.get(jwt_token, "is_mobio") is not None
+                if is_staff and typically != TYPICALLY.BEARER:
+                    raise ValueError(
+                        "admin_sdk::typically invalidated, this must is %s" % TYPICALLY.BEARER
+                    )
+                if (not is_staff) and typically != TYPICALLY.DIGEST:
+                    raise ValueError(
+                        "admin_sdk::typically invalidated, this must is %s" % TYPICALLY.DIGEST
+                    )
+                arr_token = jwt_token.split(".")
+                # kiểm tra token trong REDIS
+                verify_token = arr_token[2]
+                value = self.local_redis.get(verify_token)
+                if not value:
+                    raise ValueError("admin_sdk::verify_token: {} not found in redis".format(verify_token))
+                return jwt_token
+
+            elif typically == TYPICALLY.BASIC:
+                if not check_basic_auth_v2(jwt_token):
+                    if not MobioAuthorization.check_app_data_out(jwt_token):
+                        raise ValueError("admin_sdk:: {} basic key invalid".format(jwt_token))
+                return jwt_token
 
         except Exception as e:
             print("admin_sdk::MobioAuthorization::verify_token: ERROR: %s" % e)
