@@ -8,20 +8,18 @@
 """
 
 
-from .config import SystemConfigKeys, UrlConfig, KafkaTopic
+from .config import SystemConfigKeys, UrlConfig, KafkaTopic, CodeErrorDecrypt, CodeErrorEncrypt, RedisKeyCache
 import datetime
 import requests
 from dateutil.parser import parse
 import base64
 from .mobio_admin_sdk import MobioAdminSDK
 from .aes_cipher import CryptUtil
-from mobio.libs.ciphers import MobioCrypt2
+from mobio.libs.ciphers import MobioCrypt2, MobioCrypt4
 import json
 from flask import request
 from .aes_cipher import AESCipher
-from mobio.libs.kafka_lib.helpers.confluent_producer_manager import (
-    ConfluentProducerManager,
-)
+from mobio.libs.kafka_lib.helpers.kafka_producer_manager import KafkaProducerManager
 import os
 
 
@@ -433,10 +431,13 @@ def push_kafka_log_action_account(json_mess):
     if json_mess.get("action_name_vi") and not json_mess.get("action_name_en"):
         json_mess["action_name_en"] = json_mess.get("action_name_vi")
     json_mess["source"] = "admin_sdk"
-    ConfluentProducerManager.send_message_to_topic(
-        topic=KafkaTopic.LogActionAccount, data=json.dumps({"message": json_mess})
+    push_message_kafka(
+        topic=KafkaTopic.LogActionAccount, data={"message": json_mess}
     )
 
+def push_message_kafka(topic:str, data:dict, key=None):
+    key = key if key else topic
+    KafkaProducerManager().flush_message(topic=topic, key=key, value=data)
 
 @MobioAdminSDK.lru_cache.add()
 def get_merchant_config_host(
@@ -617,7 +618,7 @@ def get_list_api_register_app(merchant_id, app_id):
         api_url,
         params=params,
         headers=request_header,
-        timeout=2,
+        timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
     )
     response.raise_for_status()
     result = response.json()
@@ -625,3 +626,301 @@ def get_list_api_register_app(merchant_id, app_id):
         return result.get("data")
     else:
         return None
+
+@MobioAdminSDK.lru_cache.add()
+def get_list_fields_config_encrypt(merchant_id, module):
+    api_version = MobioAdminSDK().admin_version
+    adm_url = str(UrlConfig.GET_LIST_FIELD_CONFIG_ENCRYPT).format(
+        host=MobioAdminSDK().admin_host, version=api_version
+    )
+    params = {"module": module}
+    request_header = {
+        "Authorization": SystemConfigKeys.MOBIO_TOKEN,
+        "X-Merchant-Id": merchant_id
+    }
+    if MobioAdminSDK().request_header:
+        request_header.update(MobioAdminSDK().request_header)
+    response = requests.get(
+        adm_url,
+        params=params,
+        headers=request_header,
+        timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
+    )
+    response.raise_for_status()
+    result = response.json()
+    if result and result.get("data"):
+        return result.get("data")
+    else:
+        return []
+
+
+@MobioAdminSDK.lru_cache.add()
+def get_detail_kms_config(kms_id):
+    api_version = MobioAdminSDK().admin_version
+    adm_url = str(UrlConfig.GET_DETAIL_KMS_CONFIG).format(
+        host=MobioAdminSDK().admin_host, version=api_version
+    )
+    params = {"kms_id": kms_id}
+    request_header = {
+        "Authorization": SystemConfigKeys.MOBIO_TOKEN,
+    }
+    if MobioAdminSDK().request_header:
+        request_header.update(MobioAdminSDK().request_header)
+    response = requests.get(
+        adm_url,
+        params=params,
+        headers=request_header,
+        timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
+    )
+    response.raise_for_status()
+    result = response.json()
+    if result and result.get("data"):
+        return result.get("data")
+    else:
+        return {}
+
+def get_info_field_config(merchant_id, module, field):
+    field_config = {}
+    try:
+        fields_config = get_list_fields_config_encrypt(merchant_id, module)
+        if fields_config:
+            for item in fields_config:
+                if item.get("field") == field and item.get("kms_id") and item.get("enc_level") != "enc_frontend":
+                    field_config["kms_id"] = item.get("kms_id")
+                    field_config["kms_info"] = item.get("kms_info")
+                    # field_config["normalize_config"] = item.get("normalize_config", "")
+                    break
+    except Exception as e:
+        print("admin_sdk::get_kms_id_from_fields_config: error: {}".format(e))
+    return field_config
+
+def build_response_from_list(list_value):
+    data = {}
+    for item in list_value:
+        data[item] = item
+    return { "code": 200, "data": data}
+
+def encrypt_field_by_config(merchant_id, module, field, values):
+    field_config = get_info_field_config(merchant_id, module, field)
+    kms_id, kms_info = None, None
+    if field_config and isinstance(field_config, dict):
+        kms_id = field_config.get("kms_id")
+        kms_info = field_config.get("kms_info")
+    if isinstance(values, str):
+        values = [values]
+    if kms_id and kms_info:
+        kms_type = kms_info.get("kms_type", "kms_mobio")
+        if kms_type == "kms_mobio":
+            data_response = process_kms_mobio_encrypt(values)
+        elif kms_type == "kms_viettel":
+            data_response = process_kms_viettel_encrypt(kms_info, values)
+        else:
+            data_response = build_response_from_list(values)
+    else:
+        data_response = build_response_from_list(values)
+    return data_response
+
+def process_kms_mobio_encrypt(values):
+    data = {}
+    data_error = {}
+    for item in values:
+        if not item:
+            continue
+        try:
+            item_format = MobioCrypt4.e1(item)
+        except:
+            item_format = None
+        if item_format:
+            data[item] = item_format
+        else:
+            data_error[item] = CodeErrorEncrypt.encrypt_error
+    return {"data": data, "data_error": data_error}
+
+def decrypt_field_by_config(merchant_id, module, field, values):
+    field_config = get_info_field_config(merchant_id, module, field)
+    kms_id, kms_info = None, None
+    if field_config and isinstance(field_config, dict):
+        kms_id = field_config.get("kms_id")
+        kms_info = field_config.get("kms_info")
+    if isinstance(values, str):
+        values = [values]
+    if kms_id and kms_info:
+        kms_type = kms_info.get("kms_type", "kms_mobio")
+        if kms_type == "kms_mobio":
+            data_response = process_kms_mobio_decrypt(values)
+        elif kms_type == "kms_viettel":
+            data_response = process_kms_viettel_decrypt(kms_info, values)
+        else:
+            data_response = build_response_from_list(values)
+    else:
+        data_response = build_response_from_list(values)
+    return data_response
+
+def process_kms_mobio_decrypt(values):
+    data = {}
+    data_error = {}
+    for item in values:
+        if not item:
+            continue
+        try:
+            item_format = MobioCrypt4.d1(item, enc='UTF-8')
+        except:
+            item_format = None
+        if item_format:
+            data[item] = item_format
+        else:
+            data_error[item] = CodeErrorDecrypt.decrypt_error
+    return {"data": data, "data_error": data_error}
+
+def kms_viettel_get_token(kms_id):
+    try:
+        key_cache = RedisKeyCache.kms_viettel_get_token.format(kms_id)
+        token_key = MobioAdminSDK().redis_get_value(key_cache)
+        if token_key:
+            return token_key.decode('utf-8')
+        else:
+            api_version = MobioAdminSDK().admin_version
+            adm_url = str(UrlConfig.GET_TOKEN_KMS_CONFIG).format(
+                host=MobioAdminSDK().admin_host, version=api_version
+            )
+            params = {"kms_id": kms_id}
+            request_header = {
+                "Authorization": SystemConfigKeys.MOBIO_TOKEN,
+            }
+            if MobioAdminSDK().request_header:
+                request_header.update(MobioAdminSDK().request_header)
+            response = requests.get(
+                adm_url,
+                params=params,
+                headers=request_header,
+                timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
+            )
+            response.raise_for_status()
+            result = response.json()
+            if result and result.get("data"):
+                token_key = result.get("data").get("access_token")
+                expires_in = int(result.get("data").get("expires_in"))
+                expires_in = expires_in - 30 if expires_in > 30 else expires_in
+                MobioAdminSDK().redis_set_value_expire(key_cache, token_key, time_seconds=expires_in)
+                return token_key
+    except Exception as er:
+        print("admin_sdk::kms_viettel_get_token: error: {}".format(er))
+    return None
+
+def build_data_error_by_code(list_data, error_code):
+    data_error = {}
+    for item in list_data:
+        data_error[item] = error_code
+    return data_error
+
+def request_kms_viettel_encrypt(kms_info, access_token, list_data):
+    data_result = {
+        "data": {}, "data_error": {}
+    }
+    try:
+        kms_enc = kms_info.get("kms_enc")
+        api_url = kms_enc.get("api_url")
+        request_header = {
+            "Authorization": "Bearer {}".format(access_token),
+            "Content-Type": "application/json"
+        }
+        body_request = {
+            "msisdns": list_data
+        }
+        response = requests.post(
+            api_url,
+            headers=request_header,
+            data=body_request,
+            timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS
+        )
+        response.raise_for_status()
+        result = response.json()
+        print("admin_sdk:: encrypt status: {}, text: {}".format(response.status_code, result))
+        if result.get("content"):
+            for item in result.get("content"):
+                if item.get("value"):
+                    data_result["data"][item.get("key")] = item.get("value")
+                else:
+                    data_result["data_error"][item.get("key")] = CodeErrorEncrypt.encrypt_api_error
+            return data_result
+        data_result["data_error"] = build_data_error_by_code(list_data, CodeErrorEncrypt.encrypt_api_error)
+    except Exception as er:
+        print("admin_sdk::request_kms_viettel_encrypt: error: {}".format(er))
+        data_result["data_error"] = build_data_error_by_code(list_data, CodeErrorEncrypt.encrypt_api_timeout)
+    return data_result
+
+def request_kms_viettel_decrypt(kms_info, access_token, list_data):
+    data_result = {
+        "data": {}, "data_error": {}
+    }
+    try:
+        kms_dec = kms_info.get("kms_dec")
+        api_url = kms_dec.get("api_url")
+        request_header = {
+            "Authorization": "Bearer {}".format(access_token),
+            "Content-Type": "application/json"
+        }
+        body_request = {
+            "msisdns": list_data
+        }
+        response = requests.post(
+            api_url,
+            headers=request_header,
+            data=body_request,
+            timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS
+        )
+        response.raise_for_status()
+        result = response.json()
+        print("admin_sdk:: decrypt status: {}, text: {}".format(response.status_code, result))
+        if result.get("content"):
+            for item in result.get("content"):
+                if item.get("value"):
+                    data_result["data"][item.get("key")] = item.get("value")
+                else:
+                    data_result["data_error"][item.get("key")] = CodeErrorEncrypt.encrypt_api_error
+            return data_result
+        data_result["data_error"] = build_data_error_by_code(list_data, CodeErrorEncrypt.encrypt_api_error)
+    except Exception as er:
+        print("admin_sdk::request_kms_viettel_encrypt: error: {}".format(er))
+        data_result["data_error"] = build_data_error_by_code(list_data, CodeErrorEncrypt.encrypt_api_timeout)
+    return data_result
+
+def split_list(input_list, n):
+    """Yield successive n-sized chunks from l."""
+    for i in range(0, len(input_list), n):
+        yield input_list[i : i + n]
+
+def process_kms_viettel_encrypt(kms_info, list_data):
+    data_response = {"data": {}, "data_error": {}}
+    try:
+        kms_id = kms_info.get("kms_id")
+        access_token = kms_viettel_get_token(kms_id)
+        if access_token:
+            list_chunk = split_list(list_data, 50)
+            for chunk in list_chunk:
+                data_result = request_kms_viettel_encrypt(kms_info, access_token, chunk)
+                data_response["data"].update(data_result.get("data", {}))
+                data_response["data_error"].update(data_result.get("data_error", {}))
+            return data_response
+    except Exception as er:
+        print("admin_sdk::process_kms_viettel_encrypt: error: {}".format(er))
+    data_response["data_error"] = build_data_error_by_code(list_data, CodeErrorEncrypt.encrypt_api_error)
+    return data_response
+
+def process_kms_viettel_decrypt(kms_info, list_data):
+    data_response = {"data": {}, "data_error": {}}
+    try:
+        kms_id = kms_info.get("kms_id")
+        access_token = kms_viettel_get_token(kms_id)
+        if access_token:
+            list_chunk = split_list(list_data, 50)
+            for chunk in list_chunk:
+                data_result = request_kms_viettel_decrypt(kms_info, access_token, chunk)
+                data_response["data"].update(data_result.get("data", {}))
+                data_response["data_error"].update(data_result.get("data_error", {}))
+            return data_response
+    except Exception as er:
+        print("admin_sdk::process_kms_viettel_decrypt: error: {}".format(er))
+    data_response["data_error"] = build_data_error_by_code(list_data, CodeErrorEncrypt.encrypt_api_error)
+    return data_response
+
